#
# spec file for package python-PasteDeploy
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define oldpython python
Name:           python-PasteDeploy
Version:        2.1.1+git.1652668078.0f0697d
Release:        3.1
Summary:        Tool to load, configure, and compose WSGI applications and servers
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Pylons/pastedeploy
# Source:         https://github.com/Pylons/pastedeploy/archive/%%{version}.tar.gz
Source:         pastedeploy-%{version}.tar.gz
BuildRequires:  %{python_module Paste}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Paste
Requires:       python-setuptools
Provides:       python-pastedeploy = %{version}
Obsoletes:      python-pastedeploy < %{version}
BuildArch:      noarch
%ifpython2
Obsoletes:      %{oldpython}-pastedeploy < %{version}
Provides:       %{oldpython}-pastedeploy = %{version}
%endif
%python_subpackages

%description
This tool provides code to load WSGI applications and servers from URIs; these
URIs can refer to Python Eggs for INI-style configuration files. Paste Script
provides commands to serve applications based on this configuration file.

%prep
%setup -q -n pastedeploy-%{version}
%autopatch -p1

sed -i -e '/^addopts/s/ --cov//' pytest.ini

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license license.txt
# %%{python_sitelib}/[pP]aste[dD]eploy-%{version}*-info
%{python_sitelib}/[pP]aste[dD]eploy-2.1.1.dist-info
%{python_sitelib}/PasteDeploy-2.1.1*-nspkg.pth
%{python_sitelib}/paste/deploy

%changelog
* Tue Apr  1 2025 Markéta Machová <mmachova@suse.com>
- Make the dist-info name case-insensitive
* Tue Mar 25 2025 Steve Kowalik <steven.kowalik@suse.com>
- Lowercase metadata directory name.
* Tue May  9 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Mon May 16 2022 mcepl@cepl.eu
- Update to version 2.1.1+git.1652668078.0f0697d:
  * switch to f-string
  * fix up strings and upgrade format syntax
  * move fixtures into the setup code for the test suite
  * blackify/isort/flake8
  * enable linting
  * refactor to a src folder
  * remove py2 configparser shims
  * refactor package info to setup.cfg, run pyupgrade
  * fix classifiers
  * disable windows
- remove unnecessary patch rm_nspace_pkgs.patch.
* Thu Nov 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.1.1:
  * Added ``setuptools`` as an explicit dependency.
* Tue Jun 23 2020 Matej Cepl <mcepl@suse.com>
- Add rm_nspace_pkgs.patch to poorly used namespace_packages
  (gh#Pylons/pastedeploy#27)
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.1.0:
  * pytest-runner removed, use tox to run tests
* Tue Mar  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github tarball to run tests
* Tue Dec 18 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Mon Dec 17 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 2.0.1:
  * Use pytest.ini testpaths
  * Use pylons-sphinx-themes for pylons
  * Add GitHub issue templates (#13)
  * tox.ini: Drop py32; add py35
  * Remove dead links
  * Fix string-formatting args when raising LookupError
  * Eliminate cover and cover3 tox targets
  * fix link to paster serve
  * Comment out obsolete static path
  * Prepare a 2.0.0 release (#19)
  * Use .rst for extension for better rendering on GitHub
  * rename directory of reST files to use .rst extension
  * Update link to Paste, saving a redirect https://pythonpaste.readthedocs.io/en/latest/
  * Update tests to reflect new behaviour of globals and DEFAULT
  * Make 'python setup.py test' work (#5)
  * Switch to pytest
  * Remove obsolete links from navigation
  * missed one code-block highlighting
  * Add docs environment to tox. Build via `tox -e docs`.
  * Close branch pytest
  * Establish testing
  * update installation instructions
  * Move license.txt to root of repo in hopes that GitHub will find it
  * Add intersphinx and configure Python docs
  * Add rtd.txt to install pylons-sphinx-themes package
  * add docs env to tox
  * Release 2.0.1
  * Add docs_extra to setup.py
  * proper spacing
  * Update URLs in README and setup.py
  * Rename to README.rst for better rendering on GitHub
  * Use correct syntax highlighting
  * Remove link to paste.urlmap
  * fix spelling
  * tox.ini: Don't need pytest-cov in base testenv
  * Resolve deprecation warning
  * Added tag 1.5.2 for changeset a16d11053bed
  * use explicit bytes literal
  * use proper link syntax
  * Remove license from docs
  * comment out static directory via html_static_path
  * add docs/.gitignore to add _build
  * setup.py update (#17)
  * Fix broken link to get initial html docs built
  * Close branch tox_drop_py32_add_py35
  * Fix typo in docs/index.txt
  * Update link to pastescript in README.rst
  * Synch with master
  * tox.ini: enable tests on Python 3
  * Comment out templates path as it is not used
  * Add Makefile to PR so tox can build docs
  * Minor grammar fix (#21)
  * Remove obsolete script
  * Add contributing.md (#12)
  * fix paste_deploy paster template for python3
  * Use current links
  * Merged in huang1hao/pastedeploy/huang1hao/fix-typo-in-docsindextxt-1427530235567 (pull request #8)
  * Fix links to news and pip
  * Update URLs in setup.py and README (#10)
  * Modernize conf.py so we don't have to keep updating it for each release and year
  * Allow global_conf to override defaults, see: #7.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat May  6 2017 toddrme2178@gmail.com
- Fix provides/obsoletes
* Wed Apr 19 2017 hpj@urpla.net
- fix source url
* Wed Apr 19 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Fri Feb  6 2015 hpj@urpla.net
- update to version 1.5.2
  * Fixed Python 3 issue in paste.deploy.util.fix_type_error()
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Jun 13 2013 dmueller@suse.com
- add python-distribute dependency
* Sun May 27 2012 highwaystar.ru@gmail.com
- python3 package added
* Thu Sep  1 2011 saschpe@suse.de
- Added Provides/Obsoletes for python-pastedeploy
* Thu Sep  1 2011 saschpe@suse.de
- Initial version
